pub struct SingleAllocation<'a> { /* private fields */ }Expand description
Allocator which will allocate only once at a time.
Implementations
Sourceimpl SingleAllocation<'_>
impl SingleAllocation<'_>
Sourcepub fn new<T>(data: &mut [MaybeUninit<T>]) -> Self
pub fn new<T>(data: &mut [MaybeUninit<T>]) -> Self
Construct a new [OnceAllocator], which will use the data as its underlying memory.